@@ -14,7 +14,11 @@ _linking_module = None
 
 
 def activate(
-    scan_schema_name, *, create_schema=True, create_tables=True, linking_module=None
+    scan_schema_name,
+    *,
+    create_schema=True,
+    create_tables=True,
+    linking_module=None,
 ):
     """Activate this schema.
 
@@ -330,13 +334,19 @@ class ScanInfo(dj.Imported):
 
             # Insert in ScanInfo
             x_zero = (
-                scan.motor_position_at_zero[0] if scan.motor_position_at_zero else None
+                scan.motor_position_at_zero[0]
+                if scan.motor_position_at_zero
+                else None
             )
             y_zero = (
-                scan.motor_position_at_zero[1] if scan.motor_position_at_zero else None
+                scan.motor_position_at_zero[1]
+                if scan.motor_position_at_zero
+                else None
             )
             z_zero = (
-                scan.motor_position_at_zero[2] if scan.motor_position_at_zero else None
+                scan.motor_position_at_zero[2]
+                if scan.motor_position_at_zero
+                else None
             )
 
             self.insert1(
@@ -393,8 +403,12 @@ class ScanInfo(dj.Imported):
                             field_idx=plane_idx,
                             px_height=scan.image_height,
                             px_width=scan.image_width,
-                            um_height=getattr(scan, "image_height_in_microns", None),
-                            um_width=getattr(scan, "image_width_in_microns", None),
+                            um_height=getattr(
+                                scan, "image_height_in_microns", None
+                            ),
+                            um_width=getattr(
+                                scan, "image_width_in_microns", None
+                            ),
                             field_x=x_zero if x_zero else None,
                             field_y=y_zero if y_zero else None,
                             field_z=z_zero + scan.scanning_depths[plane_idx]
@@ -438,7 +452,9 @@ class ScanInfo(dj.Imported):
                     fps=sbx_meta["frame_rate"],
                     bidirectional=sbx_meta == "bidirectional",
                     nrois=sbx_meta["num_rois"] if is_multiROI else 0,
-                    scan_duration=(sbx_meta["num_frames"] / sbx_meta["frame_rate"]),
+                    scan_duration=(
+                        sbx_meta["num_frames"] / sbx_meta["frame_rate"]
+                    ),
                 )
             )
             # Insert Field(s)
@@ -474,7 +490,12 @@ class ScanInfo(dj.Imported):
 
             # Frame per second
             try:
-                fps = 1000 / nd2_file.experiment[0].parameters.periods[0].periodDiff.avg
+                fps = (
+                    1000
+                    / nd2_file.experiment[0]
+                    .parameters.periods[0]
+                    .periodDiff.avg
+                )
             except:
                 fps = 1000 / nd2_file.experiment[0].parameters.periodDiff.avg
 
@@ -495,7 +516,8 @@ class ScanInfo(dj.Imported):
                 return (tf - ti) * 86400 + 1 / fps
 
             scan_duration = sum(
-                estimate_nd2_scan_duration(nd2.ND2File(f)) for f in scan_filepaths
+                estimate_nd2_scan_duration(nd2.ND2File(f))
+                for f in scan_filepaths
             )
 
             try:
@@ -506,7 +528,9 @@ class ScanInfo(dj.Imported):
                     if re.search(("AM|PM"), scan_datetime)
                     else "%m/%d/%Y %H:%M:%S",
                 )
-                scan_datetime = datetime.strftime(scan_datetime, "%Y-%m-%d %H:%M:%S")
+                scan_datetime = datetime.strftime(
+                    scan_datetime, "%Y-%m-%d %H:%M:%S"
+                )
             except:
                 scan_datetime = None
 
@@ -581,18 +605,18 @@ class ScanInfo(dj.Imported):
             )
 
             self.Field.insert(
-                dict(
-                    key,
-                    field_idx=plane_idx,
-                    px_height=pvscan_info["height_in_pixels"],
-                    px_width=pvscan_info["width_in_pixels"],
-                    um_height=pvscan_info["height_in_um"],
-                    um_width=pvscan_info["width_in_um"],
-                    field_x=pvscan_info["fieldX"],
-                    field_y=pvscan_info["fieldY"],
-                    field_z=pvscan_info["fieldZ"][plane_idx],
-                )
-                for plane_idx in range(pvscan_info["num_planes"])
+                    dict(
+                        key,
+                        field_idx=plane_idx,
+                        px_height=pvscan_info["height_in_pixels"],
+                        px_width=pvscan_info["width_in_pixels"],
+                        um_height=pvscan_info["height_in_um"],
+                        um_width=pvscan_info["width_in_um"],
+                        field_x=pvscan_info["fieldX"],
+                        field_y=pvscan_info["fieldY"],
+                        field_z=pvscan_info["fieldZ"] if pvscan_info["num_planes"] == 1 else pvscan_info["fieldZ"][plane_idx],
+                    )
+                    for plane_idx in range(pvscan_info["num_planes"])
             )
         else:
             raise NotImplementedError(
@@ -601,9 +625,12 @@ class ScanInfo(dj.Imported):
             )
 
         # Insert file(s)
-        root_dir = find_root_directory(get_imaging_root_data_dir(), scan_filepaths[0])
+        root_dir = find_root_directory(
+            get_imaging_root_data_dir(), scan_filepaths[0]
+        )
 
         scan_files = [
-            pathlib.Path(f).relative_to(root_dir).as_posix() for f in scan_filepaths
+            pathlib.Path(f).relative_to(root_dir).as_posix()
+            for f in scan_filepaths
         ]
         self.ScanFile.insert([{**key, "file_path": f} for f in scan_files])
